==> ajv-1.4.9.tgz: package/lib/dotjs/pattern.js <==
'use strict';
module.exports = function generate_pattern(it) {
  var out = ' ';
  var $lvl = it.level,
    $dataLvl = it.dataLevel,
    $schema = it.schema['pattern'],
    $schemaPath = it.schemaPath + '.' + 'pattern',
    $breakOnError = !it.opts.allErrors;
  var $data = 'data' + ($dataLvl || ''),
    $valid = 'valid' + $lvl,
    $errs = 'errs' + $lvl;
  new RegExp($schema);
  out += 'if (! ' + (it.usePattern($schema)) + '.test(' + ($data) + ') ) {  ';
  if (!it.compositeRule && $breakOnError) {
    out += ' validate.errors = [ { keyword: \'' + ('pattern') + '\', dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should match pattern "' + (it.util.escapeQuotes($schema)) + '"\' ';
    }
    if (it.opts.verbose || it.opts.i18n) {
      out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' ';
    }
    if (it.opts.verbose) {
      out += ' , data: ' + ($data) + ' ';
    }
    if (it.opts.i18n) {
      out += ', params: { escaped: \'' + (it.util.escapeQuotes($schema)) + '\' }';
    }
    out += ' }]; return false; ';
  } else {
    out += '  var err =   { keyword: \'' + ('pattern') + '\', dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should match pattern "' + (it.util.escapeQuotes($schema)) + '"\' ';
    }
    if (it.opts.verbose || it.opts.i18n) {
      out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' ';
    }
    if (it.opts.verbose) {
      out += ' , data: ' + ($data) + ' ';
    }
    if (it.opts.i18n) {
      out += ', params: { escaped: \'' + (it.util.escapeQuotes($schema)) + '\' }';
    }
    out += ' }; if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
  }
  out += '} ';
  if ($breakOnError) {
    out += ' else { ';
  }
  return out;
}

==> ajv-2.2.2.tgz: package/lib/dotjs/pattern.js <==
'use strict';
module.exports = function generate_pattern(it) {
  var out = ' ';
  var $lvl = it.level,
    $dataLvl = it.dataLevel,
    $schema = it.schema['pattern'],
    $schemaPath = it.schemaPath + '.' + 'pattern',
    $breakOnError = !it.opts.allErrors;
  var $data = 'data' + ($dataLvl || ''),
    $valid = 'valid' + $lvl,
    $errs = 'errs' + $lvl;
  new RegExp($schema);
  out += 'if (! ' + (it.usePattern($schema)) + '.test(' + ($data) + ') ) {  ';
  if (!it.compositeRule && $breakOnError) {
    out += ' validate.errors = [ { keyword: \'' + ('pattern') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { pattern: \'' + (it.util.escapeQuotes($schema)) + '\' } ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should match pattern "' + (it.util.escapeQuotes($schema)) + '"\' ';
    }
    if (it.opts.verbose) {
      out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' , data: ' + ($data) + ' ';
    }
    out += ' }]; return false; ';
  } else {
    out += '  var err =   { keyword: \'' + ('pattern') + '\' , dataPath: (dataPath || \'\') + ' + (it.errorPath) + ' , schemaPath: "' + ($schemaPath) + '" , params: { pattern: \'' + (it.util.escapeQuotes($schema)) + '\' } ';
    if (it.opts.messages !== false) {
      out += ' , message: \'should match pattern "' + (it.util.escapeQuotes($schema)) + '"\' ';
    }
    if (it.opts.verbose) {
      out += ' , schema: ' + (it.util.toQuotedString($schema)) + ' , data: ' + ($data) + ' ';
    }
    out += ' }; if (vErrors === null) vErrors = [err]; else vErrors.push(err); errors++; ';
  }
  out += '} ';
  if ($breakOnError) {
    out += ' else { ';
  }
  return out;
}
